← Back to team overview

bigdata-dev team mailing list archive

[Merge] lp:~bigdata-dev/charms/trusty/apache-hadoop-plugin/trunk into lp:charms/trusty/apache-hadoop-plugin

 

Kevin W Monroe has proposed merging lp:~bigdata-dev/charms/trusty/apache-hadoop-plugin/trunk into lp:charms/trusty/apache-hadoop-plugin.

Requested reviews:
  Juju Big Data Development (bigdata-dev)

For more details, see:
https://code.launchpad.net/~bigdata-dev/charms/trusty/apache-hadoop-plugin/trunk/+merge/271164
-- 
Your team Juju Big Data Development is requested to review the proposed merge of lp:~bigdata-dev/charms/trusty/apache-hadoop-plugin/trunk into lp:charms/trusty/apache-hadoop-plugin.
=== modified file 'hooks/common.py' (properties changed: +x to -x)
=== added file 'resources/python/jujuresources-0.2.11.tar.gz'
Binary files resources/python/jujuresources-0.2.11.tar.gz	1970-01-01 00:00:00 +0000 and resources/python/jujuresources-0.2.11.tar.gz	2015-09-15 17:35:07 +0000 differ
=== removed file 'resources/python/jujuresources-0.2.9.tar.gz'
Binary files resources/python/jujuresources-0.2.9.tar.gz	2015-07-24 15:36:09 +0000 and resources/python/jujuresources-0.2.9.tar.gz	1970-01-01 00:00:00 +0000 differ
=== modified file 'tests/01-basic-deployment.py'
--- tests/01-basic-deployment.py	2015-03-04 00:07:45 +0000
+++ tests/01-basic-deployment.py	2015-09-15 17:35:07 +0000
@@ -6,7 +6,7 @@
 
 class TestDeploy(unittest.TestCase):
     """
     Basic deployment test for Apache Hadoop Client.
 
     This charm cannot do anything useful by itself, so integration testing
     is done in the bundle.
@@ -16,8 +16,10 @@
     def setUpClass(cls):
         cls.d = amulet.Deployment(series='trusty')
         cls.d.add('apache-hadoop-client')
-        cls.d.setup(timeout=9000)
-        cls.d.sentry.wait()
+        cls.d.add('apache-hadoop-plugin')
+        cls.d.relate('apache-hadoop-client:hadoop-plugin', 'apache-hadoop-plugin:hadoop-plugin')
+        cls.d.setup(timeout=900)
+        cls.d.sentry.wait(timeout=1800)
         cls.unit = cls.d.sentry.unit['apache-hadoop-client/0']
 
     def test_deploy(self):
@@ -6,7 +6,7 @@
 class TestDeploy(unittest.TestCase):
     """
-    Basic deployment test for Apache Hadoop Client.
+    Basic deployment test for Apache Hadoop plugin.
 
     This charm cannot do anything useful by itself, so integration testing


Follow ups